Customer class

Constructors

Customer({int? id, required String name, required String phoneNumber, required String customerType, required int creditPoints})
Customer.fromMap(Map<String, dynamic> map)
factory

Properties

creditPoints int
final
customerType String
final
hashCode int
The hash code for this object.
no setterinherited
id int?
final
name String
final
phoneNumber String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? id, String? name, String? phoneNumber, String? customerType, int? creditPoints}) Customer
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited