DatabaseHelper class

Properties

database Future<Database>
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() Future
createCustomer(Customer customer) Future<int>
deleteCustomer(int id) Future<int>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
readAllCustomers() Future<List<Customer>>
readCustomer(int id) Future<Customer?>
toString() String
A string representation of this object.
inherited
updateCustomer(Customer customer) Future<int>

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance DatabaseHelper
final